import logging
from logging.handlers import QueueHandler
from queue import Queue
import os
from datetime import datetime

from flask import current_app

def init_logger(config):
    LOG_DIR = config.get('LOGGING', {}).get('LOG_DIR', 'log')

    if not os.path.exists(LOG_DIR):
        os.makedirs(LOG_DIR)

    log_file_name = os.path.join(LOG_DIR, datetime.now().strftime('%Y-%m-%d-%H-%M') + '.log')

    logger = logging.getLogger(__name__)
    logger.setLevel(logging.DEBUG)

    file_handler = logging.FileHandler(log_file_name, mode='w')
    file_handler.setLevel(logging.DEBUG)
    formatter = logging.Formatter('%(asctime)s - %(levelname)s: %(message)s',
                                datefmt='%m/%d/%Y %I:%M:%S %p')
    file_handler.setFormatter(formatter)
    logger.addHandler(file_handler)

    log_queue = Queue()
    queue_handler = QueueHandler(log_queue)
    queue_handler.setLevel(logging.DEBUG)
    logger.addHandler(queue_handler)

    logger.debug("Logger initialized")
    
    return logger